hasPath function
Matcher
hasPath(
- dynamic path
Returns a Matcher that matches path against an entity's path.
path may be a String, a predicate function, or a Matcher. If it is
a String, it will be wrapped in an equality matcher.
Implementation
Matcher hasPath(dynamic path) => _HasPath(path);