isFileSystemException function
Matcher
isFileSystemException([
- dynamic osErrorCode
Returns a Matcher that successfully matches against an instance of
FileSystemException.
If osErrorCode is specified, matches will be limited to exceptions whose
osError.errorCode also match the specified matcher.
osErrorCode may be an int, a predicate function, or a Matcher. If it
is an int, it will be wrapped in an equality matcher.
Implementation
Matcher isFileSystemException([dynamic osErrorCode]) =>
_FileSystemException(osErrorCode);