throwsFileSystemException function
Matcher
throwsFileSystemException([
- dynamic osErrorCode
Returns a matcher that successfully matches against a future or function that throws a FileSystemException.
If osErrorCode is specified, matches will be limited to exceptions whose
osError.errorCode also match the specified matcher.
osErrorCode may be an int, a predicate function, or a Matcher. If it
is an int, it will be wrapped in an equality matcher.
Implementation
Matcher throwsFileSystemException([dynamic osErrorCode]) =>
throwsA(isFileSystemException(osErrorCode));